@@ -2,99 +2,95 @@ package Data::Validation;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.20.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
-use Data::Validation::Constants;
+use Data::Validation::Constants qw( EXCEPTION_CLASS FALSE HASH NUL SPC );
 use Data::Validation::Constraints;
 use Data::Validation::Filters;
-use English                 qw( -no_match_vars );
-use List::Util              qw( first );
+use Data::Validation::Utils     qw( throw );
+use List::Util                  qw( first );
 use Try::Tiny;
-use Unexpected::Types       qw( HashRef NonZeroPositiveInt );
-use Unexpected::Functions   qw( FieldComparison ValidationErrors );
+use Unexpected::Functions       qw( FieldComparison ValidationErrors );
+use Unexpected::Types           qw( HashRef NonZeroPositiveInt );
 use Moo;
 
 has 'constraints' => is => 'ro', isa => HashRef, default => sub { {} };
 
-has 'level'       => is => 'ro', isa => NonZeroPositiveInt, default => 1;
-
 has 'fields'      => is => 'ro', isa => HashRef, default => sub { {} };
 
 has 'filters'     => is => 'ro', isa => HashRef, default => sub { {} };
 
-has '_operators'  => is => 'ro', isa => HashRef, default => sub {
-   { 'eq' => sub { $_[ 0 ] eq $_[ 1 ] },
-     '==' => sub { $_[ 0 ] == $_[ 1 ] },
-     'ne' => sub { $_[ 0 ] ne $_[ 1 ] },
-     '!=' => sub { $_[ 0 ] != $_[ 1 ] },
-     '>'  => sub { $_[ 0 ] >  $_[ 1 ] },
-     '>=' => sub { $_[ 0 ] >= $_[ 1 ] },
-     '<'  => sub { $_[ 0 ] <  $_[ 1 ] },
-     '<=' => sub { $_[ 0 ] <= $_[ 1 ] }, } };
+has 'level'       => is => 'ro', isa => NonZeroPositiveInt, default => 1;
 
 # Private functions
+my $_comparisons = sub {
+   return { 'eq' => sub { $_[ 0 ] eq $_[ 1 ] },
+            '==' => sub { $_[ 0 ] == $_[ 1 ] },
+            'ne' => sub { $_[ 0 ] ne $_[ 1 ] },
+            '!=' => sub { $_[ 0 ] != $_[ 1 ] },
+            '>'  => sub { $_[ 0 ] >  $_[ 1 ] },
+            '>=' => sub { $_[ 0 ] >= $_[ 1 ] },
+            '<'  => sub { $_[ 0 ] <  $_[ 1 ] },
+            '<=' => sub { $_[ 0 ] <= $_[ 1 ] }, };
+};
+
 my $_get_methods = sub {
-   return split SPC, $_[ 0 ] || NUL;
+   return split SPC, $_[ 0 ] // NUL;
 };
 
 my $_should_compare = sub {
    return first { $_ eq 'compare' } $_get_methods->( $_[ 0 ]->{validate} );
 };
 
-my $_throw = sub {
-   EXCEPTION_CLASS->throw( @_ );
-};
-
 # Private methods
 my $_filter = sub {
-   my ($self, $filters, $id, $value) = @_;
+   my ($self, $filters, $id, $v) = @_;
 
    for my $method ($_get_methods->( $filters )) {
-      my %attr    = ( %{ $self->filters->{ $id } || {} }, method => $method, );
-      my $dvf_obj = Data::Validation::Filters->new( %attr );
+      my $attr    = { %{ $self->filters->{ $id } // {} }, method => $method, };
+      my $dvf_obj = Data::Validation::Filters->new_from_method( $attr );
 
-      $value = $dvf_obj->filter_value( $value );
+      $v = $dvf_obj->filter( $v );
    }
 
-   return $value;
+   return $v;
 };
 
 my $_compare_fields = sub {
    my ($self, $prefix, $form, $lhs_name) = @_;
 
    my $id         = $prefix.$lhs_name;
-   my $constraint = $self->constraints->{ $id } || {};
+   my $constraint = $self->constraints->{ $id } // {};
    my $rhs_name   = $constraint->{other_field}
-      or $_throw->( 'Constraint [_1] has no comparison field', [ $id ] );
-   my $op         = $constraint->{operator} || 'eq';
-   my $lhs        = $form->{ $lhs_name } || NUL;
-   my $rhs        = $form->{ $rhs_name } || NUL;
-   my $bool       = exists $self->_operators->{ $op }
-                  ? $self->_operators->{ $op }->( $lhs, $rhs ) : 0;
+      or throw 'Constraint [_1] has no comparison field',
+               [ $id ], class => 'Constraint';
+   my $op         = $constraint->{operator} // 'eq';
+   my $handler    = $_comparisons->()->{ $op }
+      or throw 'Constraint [_1] unknown comparison operator [_2]',
+               [ $id, $op ], class => 'Constraint';
+   my $lhs        = $form->{ $lhs_name } // NUL;
+   my $rhs        = $form->{ $rhs_name } // NUL;
 
-   unless ($bool) {
-      $lhs_name = $self->fields->{ $prefix.$lhs_name }->{label} || $lhs_name;
-      $rhs_name = $self->fields->{ $prefix.$rhs_name }->{label} || $rhs_name;
+   $handler->( $lhs, $rhs ) and return;
 
-      $_throw->( FieldComparison, [ $lhs_name, $op, $rhs_name ] );
-   }
-
-   return;
+   $lhs_name = $self->fields->{ $prefix.$lhs_name }->{label} // $lhs_name;
+   $rhs_name = $self->fields->{ $prefix.$rhs_name }->{label} // $rhs_name;
+   throw FieldComparison, [ $lhs_name, $op, $rhs_name ];
 };
 
 my $_validate = sub {
-   my ($self, $method, $id, $value) = @_;
+   my ($self, $valids, $id, $v) = @_;
 
-   my %attr = ( %{ $self->constraints->{ $id } || {} }, method => $method, );
-   my $constraint = Data::Validation::Constraints->new( %attr );
+   for my $method (grep { $_ ne 'compare' } $_get_methods->( $valids )) {
+      my $attr = { %{ $self->constraints->{ $id } // {} }, method => $method, };
+      my $constraint = Data::Validation::Constraints->new_from_method( $attr );
+
+      $constraint->validate( $v ) and next;
 
-   unless ($constraint->validate_value( $value )) {
      (my $class = $method) =~ s{ \A is }{}mx;
-      my $name  = $self->fields->{ $id }->{label}
-               || $self->fields->{ $id }->{fhelp} # Deprecated
-               || $id;
+      my $name  = $self->fields->{ $id }->{label} // $id;
 
-      $_throw->( sub { $class }, [ $name, $value ], level => $self->level);
+      throw sub { $class }, [ $name, $v ], level => $self->level;
    }
 
    return;
@@ -104,42 +100,40 @@ my $_validate = sub {
 sub check_form { # Validate all fields on a form by repeated calling check_field
    my ($self, $prefix, $form) = @_; my @errors = (); $prefix ||= NUL;
 
-   ($form and ref $form eq HASH) or $_throw->( 'Form bad hash' );
+   ($form and ref $form eq HASH)
+      or throw 'Form bad hash', class => 'Constraint';
 
    for my $name (sort keys %{ $form }) {
-      my $id = $prefix.$name; my $field = $self->fields->{ $id };
+      my $id = $prefix.$name; my $conf = $self->fields->{ $id };
 
-      ($field and ($field->{filters} or $field->{validate})) or next;
+      ($conf and ($conf->{filters} or $conf->{validate})) or next;
 
       try   {
          $form->{ $name } = $self->check_field( $id, $form->{ $name } );
-         $_should_compare->( $field )
+         $_should_compare->( $conf )
             and $self->$_compare_fields( $prefix, $form, $name );
       }
       catch { push @errors, $_ };
    }
 
-   @errors and $_throw->( ValidationErrors, \@errors, level => 2 );
+   @errors and throw ValidationErrors, \@errors, level => 2;
 
    return $form;
 }
 
-sub check_field { # Validate form field values
-   my ($self, $id, $value) = @_; my $field;
+sub check_field { # Validate a single form field value
+   my ($self, $id, $v) = @_; my $conf;
 
-   unless ($id and $field = $self->fields->{ $id }
-           and ($field->{filters} or $field->{validate})) {
-      $_throw->( 'Field [_1] undefined', [ $id, $value ] );
+   unless ($id and $conf = $self->fields->{ $id }
+           and ($conf->{filters} or $conf->{validate})) {
+      throw 'Field [_1] validation configuration not found',
+            [ $id, $v ], class => 'Constraint';
    }
 
-   $field->{filters}
-      and $value = $self->$_filter( $field->{filters}, $id, $value );
+   $conf->{filters } and $v = $self->$_filter( $conf->{filters }, $id, $v );
+   $conf->{validate} and    $self->$_validate( $conf->{validate}, $id, $v );
 
-   for my $method ($_get_methods->( $field->{validate} )) {
-      $method eq 'compare' or $self->$_validate( $method, $id, $value );
-   }
-
-   return $value;
+   return $v;
 }
 
 1;
@@ -148,7 +142,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding utf-8
 
 =begin html
 
@@ -164,7 +158,7 @@ Data::Validation - Filter and validate data values
 
 =head1 Version
 
-Describes version v0.20.$Rev: 1 $ of L<Data::Validation>
+Describes version v0.21.$Rev: 1 $ of L<Data::Validation>
 
 =head1 Synopsis
 
@@ -191,9 +185,9 @@ Describes version v0.20.$Rev: 1 $ of L<Data::Validation>
       my ($self, $config) = @_;
 
       return Data::Validation->new( {
-         constraints => $config->{constraints}     || {},
-         fields      => $config->{fields}          || {},
-         filters     => $config->{filters}         || {} } );
+         constraints => $config->{constraints} // {},
+         fields      => $config->{fields}      // {},
+         filters     => $config->{filters}     // {} } );
    }
 
 =head1 Description
@@ -208,40 +202,33 @@ otherwise an exception is thrown
 
 =head1 Configuration and Environment
 
-The following are passed to the constructor
+Defines the following attributes;
 
 =over 3
 
-=item constraints
+=item C<constraints>
 
-Hash containing constraint attributes. Keys are the C<$id> values passed
+Hash containing constraint attributes. Keys are the C<id> values passed
 to L</check_field>. See L<Data::Validation::Constraints>
 
-=item fields
+=item C<fields>
 
-Hash containing field definitions. Keys are the C<$id> values passed
+Hash containing field definitions. Keys are the C<id> values passed
 to L</check_field>. Each field definition can contain a space
 separated list of filters to apply and a space separated list of
 constraints. Each constraint method must return true for the value to
 be accepted
 
-=item filters
+=item C<filters>
 
-Hash containing filter attributes. Keys are the C<$id> values passed
+Hash containing filter attributes. Keys are the C<id> values passed
 to L</check_field>. See L<Data::Validation::Filters>
 
-=item level
+=item C<level>
 
 Positive integer defaults to 1. Used to select the stack frame from which
 to throw the C<check_field> exception
 
-=item operators
-
-Hash containing operator code refs. The keys of the hash ref are comparison
-operators and their values are the anonymous code refs that compare
-the operands and return a boolean. Used by the I<compare> form validation
-method
-
 =back
 
 =head1 Subroutines/Methods
@@ -250,14 +237,14 @@ method
 
    $form = $dv->check_form( $prefix, $form );
 
-Calls L</check_field> for each of the keys in the C<$form> hash. In
-the calls to L</check_field> the C<$form> keys have the C<$prefix>
-prepended to them to create the key to the C<$fields> hash
+Calls L</check_field> for each of the keys in the C<form> hash. In
+the calls to L</check_field> the C<form> keys have the C<prefix>
+prepended to them to create the key to the C<fields> hash
 
-If one of the fields constraint names is I<compare>, then the fields
+If one of the fields constraint names is C<compare>, then the fields
 value is compared with the value for another field. The constraint
-attribute I<other_field> determines which field to compare and the
-I<operator> constraint attribute gives the comparison operator which
+attribute C<other_field> determines which field to compare and the
+C<operator> constraint attribute gives the comparison operator which
 defaults to C<eq>
 
 All fields are checked. Multiple error objects are stored, if they occur,
@@ -267,8 +254,8 @@ in the C<args> attribute of the returned error object
 
    $value = $dv->check_field( $id, $value );
 
-Checks one value for conformance. The C<$id> is used as a key to the
-I<fields> hash whose I<validate> attribute contains the list of space
+Checks one value for conformance. The C<id> is used as a key to the
+C<fields> hash whose C<validate> attribute contains the list of space
 separated constraint names. The value is tested against each
 constraint in turn. All tests must pass or the subroutine will use the
 C<EXCEPTION_CLASS> class to C<throw> an error
@@ -285,7 +272,7 @@ None
 
 =item L<Try::Tiny>
 
-=item L<Unexpected::Types>
+=item L<Unexpected>
 
 =back
 
@@ -298,9 +285,12 @@ documentation
 
 =head1 Bugs and Limitations
 
-There are no known bugs in this module.
-Please report problems to the address below.
-Patches are welcome
+There are no known bugs in this module. Please report problems to
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Data-Validation.  Patches are welcome
+
+=head1 Acknowledgements
+
+Larry Wall - For the Perl programming language
 
 =head1 Author
 
@@ -308,7 +298,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
