@@ -6,14 +6,16 @@ use parent qw( Exporter::Tiny );
 
 use Data::Validation::Exception;
 
-our @EXPORT = qw( EXCEPTION_CLASS HASH NUL SPC );
+our @EXPORT = qw( EXCEPTION_CLASS FALSE HASH NUL SPC TRUE );
 
 my $Exception_Class = 'Data::Validation::Exception';
 
 sub EXCEPTION_CLASS () { __PACKAGE__->Exception_Class }
+sub FALSE           () { 0      }
 sub HASH            () { 'HASH' }
 sub NUL             () { q()    }
 sub SPC             () { q( )   }
+sub TRUE            () { 1      }
 
 sub Exception_Class {
    my ($self, $class) = @_; defined $class or return $Exception_Class;
@@ -30,7 +32,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding utf-8
 
 =head1 Name
 
@@ -55,6 +57,10 @@ Defines the following attributes;
 Class name used to throw exceptions. Defaults to the value of the class
 attribute
 
+=item C<FALSE>
+
+The digit zero
+
 =item C<HASH>
 
 The string C<HASH>
@@ -67,6 +73,10 @@ The null string
 
 The space character
 
+=item C<TRUE>
+
+The digit one
+
 =back
 
 =head1 Subroutines/Methods
@@ -107,7 +117,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2014 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
