@@ -2,65 +2,75 @@ package Data::Validation::Filters;
 
 use namespace::autoclean;
 
-use Data::Validation::Constants;
-use Scalar::Util      qw( blessed );
-use Unexpected::Types qw( Str );
+use Data::Validation::Constants qw( EXCEPTION_CLASS HASH TRUE );
+use Data::Validation::Utils     qw( load_class );
+use Unexpected::Types           qw( Str );
 use Moo;
 
-with q(Data::Validation::Utils);
+has 'method'  => is => 'ro', isa => Str, required => TRUE;
 
-has 'replace' => is => 'rw', isa => Str;
+has 'pattern' => is => 'ro', isa => Str;
 
-sub filter_value {
-   my ($self, $val) = @_; defined $val or return; my $method = $self->method;
+has 'replace' => is => 'ro', isa => Str;
 
-   $self->can( $method ) and return $self->$method( $val );
+sub new_from_method {
+   my $class = shift; my $attr = ref $_[ 0 ] eq HASH ? $_[ 0 ] : { @_ };
 
-   return $self->load_class( 'filter', $method )->filter( $val );
+   $class->can( $attr->{method} ) and return $class->new( $attr );
+
+   return (load_class $class, 'filter', $attr->{method})->new( $attr );
 }
 
+sub filter {
+   my ($self, $v) = @_; my $method = $self->method; return $self->$method( $v );
+}
+
+around 'filter' => sub {
+   my ($orig, $self, $v) = @_; return defined $v ? $orig->( $self, $v ) : undef;
+};
+
 # Builtin factory filter methods
 sub filterEscapeHTML {
-   my ($self, $val) = @_;
+   my ($self, $v) = @_;
 
-   $val =~ s{ &(?!(amp|lt|gt|quot);) }{&amp;}gmx;
-   $val =~ s{ < }{&lt;}gmx;
-   $val =~ s{ > }{&gt;}gmx;
-   $val =~ s{ \" }{&quot;}gmx;
-   return $val;
+   $v =~ s{ &(?!(amp|lt|gt|quot);) }{&amp;}gmx;
+   $v =~ s{ < }{&lt;}gmx;
+   $v =~ s{ > }{&gt;}gmx;
+   $v =~ s{ \" }{&quot;}gmx;
+   return $v;
 }
 
 sub filterLowerCase {
-   my ($self, $val) = @_; return lc $val;
+   my ($self, $v) = @_; return lc $v;
 }
 
 sub filterNonNumeric {
-   my ($self, $val) = @_; $val =~ s{ \D+ }{}gmx; return $val;
+   my ($self, $v) = @_; $v =~ s{ \D+ }{}gmx; return $v;
 }
 
 sub filterReplaceRegex {
-   my ($self, $val) = @_;
+   my ($self, $v) = @_;
 
-   my $pattern = $self->pattern or return $val;
+   my $pattern = $self->pattern or return $v;
    my $replace = defined $self->replace ? $self->replace : q();
 
-   $val =~ s{ $pattern }{$replace}gmx;
-   return $val;
+   $v =~ s{ $pattern }{$replace}gmx;
+   return $v;
 }
 
 sub filterTrimBoth {
-   my ($self, $val) = @_;
+   my ($self, $v) = @_;
 
-   $val =~ s{ \A \s+ }{}mx; $val =~ s{ \s+ \z }{}mx;
-   return $val;
+   $v =~ s{ \A \s+ }{}mx; $v =~ s{ \s+ \z }{}mx;
+   return $v;
 }
 
 sub filterUpperCase {
-   my ($self, $val) = @_; return uc $val;
+   my ($self, $v) = @_; return uc $v;
 }
 
 sub filterWhiteSpace {
-   my ($self, $val) = @_; $val =~ s{ \s+ }{}gmx; return $val;
+   my ($self, $v) = @_; $v =~ s{ \s+ }{}gmx; return $v;
 }
 
 sub filterZeroLength {
@@ -73,6 +83,8 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 Name
 
 Data::Validation::Filters - Filter data values
@@ -83,7 +95,7 @@ Data::Validation::Filters - Filter data values
 
    %config = ( method => $method, %{ $self->filters->{ $id } || {} } );
 
-   $filter_ref = Data::Validation::Filters->new( %config );
+   $filter_ref = Data::Validation::Filters->new_from_method( %config );
 
    $value = $filter_ref->filter_value( $value );
 
@@ -94,12 +106,20 @@ value
 
 =head1 Configuration and Environment
 
-Uses the L<Moo::Role> L<Data::Validation::Utils>. Defines the
-following attributes:
+Defines the following attributes:
 
 =over 3
 
-=item replace
+=item C<method>
+
+Name of the constraint to apply. Required
+
+=item C<pattern>
+
+Used by L</isMathchingRegex> as the pattern to match the supplied value
+against
+
+=item C<replace>
 
 The replacement value used in regular expression search and replace
 operations
@@ -108,13 +128,14 @@ operations
 
 =head1 Subroutines/Methods
 
-=head2 filter_value
+=head2 new_from_method
 
-Calls either a builtin method or an external one to filter the data value
+A class method which implements a factory pattern using the C<method> attribute
+to select the subclass
 
 =head2 filter
 
-Should have been overridden in an external filter subclass
+Calls either a builtin method or an external one to filter the data value
 
 =head2 filterEscapeHTML
 
@@ -158,7 +179,7 @@ None
 
 =item L<Moo>
 
-=item L<Unexpected::Types>
+=item L<Unexpected>
 
 =back
 
@@ -168,9 +189,12 @@ There are no known incompatibilities in this module
 
 =head1 Bugs and Limitations
 
-There are no known bugs in this module.
-Please report problems to the address below.
-Patches are welcome
+There are no known bugs in this module. Please report problems to
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Data-Validation.  Patches are welcome
+
+=head1 Acknowledgements
+
+Larry Wall - For the Perl programming language
 
 =head1 Author
 
@@ -178,7 +202,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
